# Examples

```{toctree}
:maxdepth: 2

sample-data.ipynb
get-model-grid.ipynb
eos.ipynb
region-mask.ipynb
lateral-fill-idealized.ipynb
lateral-fill-model-grid.ipynb
pop_div_curl_xr_xgcm_metrics_compare.ipynb
CloseHeatBudget_POP2.ipynb
xgcm-transform.ipynb
xoak-example.ipynb
cesm-cmip-cf-xarray.ipynb
```
